==> haskell-lsp-test-0.15.0.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-4Yu5IZFAx9R1ujRy8s18RG
key:                  lsp-test-0.15.0.1-4Yu5IZFAx9R1ujRy8s18RG
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  ea5b71537e1155abfe10720078b7ddc5
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-4BhwIVcG1LCePiTj9eZi9:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-4BhwIVcG1LCePiTj9eZi9:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-4BhwIVcG1LCePiTj9eZi9:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-4Yu5IZFAx9R1ujRy8s18RG
depends:
    Diff-0.5-3fWbMSZyrbJIXl91nyKDLU Glob-0.10.2-GVErYq8beGKEFh7ozQbSk5
    aeson-2.1.2.1-DAjCoZEGWBTDXHPn96Kb1j
    aeson-pretty-0.8.10-9DH6Hkbn0Vw9xdd4TlCy61
    ansi-terminal-1.0.2-2td7snMYnP5JakUmenPhL1
    async-2.2.5-DLLO0Mnvxu7HErYx4gsRCE base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-IVc4JLhleBcKoxv5Dw511h
    conduit-1.3.6.1-LOP5sjciwZZGtwvmGKv7ZW
    conduit-parse-0.2.1.1-3gpBUqYXPYwBkIsxBiCEms containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    lens-5.3.2-5iQf9T9ZD7E1oav0YIbKON lsp-2.1.0.0-5nPM6areWSKJozY5QTrQE
    lsp-types-2.0.1.0-4BhwIVcG1LCePiTj9eZi9 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    row-types-1.0.1.2-D1KlpGrnNKv79rdS0OmUHV
    some-1.0.6-KVr2xKoodpQEz21w3ZX7aM text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.15.0.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-HQqFKWQnN8VFXgmjy6dtXN
key:                  lsp-test-0.15.0.1-HQqFKWQnN8VFXgmjy6dtXN
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  8315e014c1cef205841cd64688c208e8
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-IMQxeBEGCdRGmzeiiwonCf:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-IMQxeBEGCdRGmzeiiwonCf:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-IMQxeBEGCdRGmzeiiwonCf:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-HQqFKWQnN8VFXgmjy6dtXN
depends:
    Diff-0.5-As7oyl54eJ7L4x4oG6FyFm Glob-0.10.2-1pP7Rnnh9j6GezkRZB9k2v
    aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY
    aeson-pretty-0.8.10-5DpWNueRj20JJgSXuEWCvq
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU
    async-2.2.5-GQPCMKT2tm99KQt4aOAXPc base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-GhJO8BTQBcX39sPJgGPAVc
    conduit-1.3.6.1-9vefuhKp6h51CmtiJP6Shb
    conduit-parse-0.2.1.1-HWVpaCAnoFaG2wA8rAYiB3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    lens-5.3.2-Exg2qZYOG9zJ2AlH8CiZ0W
    lsp-2.1.0.0-H4YQXeowIYYF1u0BIVs9vq
    lsp-types-2.0.1.0-IMQxeBEGCdRGmzeiiwonCf mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    row-types-1.0.1.2-47ZdBxMYPEd9TzqcRPYv2l
    some-1.0.6-Dxh5LSBpEgBF9aAOdkhMvL text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
